==> rapid_widgets_library-0.2.38.tar.gz: lib/custom-borderless-card.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget customBorderlessCard(
    MaterialCardData data, Function(String, int) callback) {
  void onPressed() {}
  return Container(
    decoration: BoxDecoration(
      border: Border(
        bottom: BorderSide(width: 0.4, color: Color(0xff707070)),
      ),
      color: (data.containerbgColor != null)
          ? data.containerbgColor
          : Colors.white,
    ),
    height: (data.containerHeight != null) ? data.containerHeight : 188.5,
    width: (data.containerWidth != null) ? data.containerWidth : 360,
    child: Column(
      children: <Widget>[
        Row(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Image.network(
              (data.imgPath != null)
                  ? data.imgPath
                  : 'http://104.40.75.137:9003/assets/cms/book2.png',
              height: 113,
              width: 77,
            ),
            Padding(
              padding: const EdgeInsets.only(left: 10.0),
              child: Container(
                width: 193,
                child: Align(
                  alignment: Alignment.centerLeft,
                  child: Column(
                    children: <Widget>[
                      Text(
                        (data.title != null)
                            ? data.title
                            : 'React Fullstack with node/express',
                        style: TextStyle(
                            fontSize: 20,
                            color: Color(0xff707070),
                            fontFamily: 'Segoe UI'),
                      ),
                      SizedBox(
                        height: 11,
                      ),
                      Text(
                        (data.subtitle != null)
                            ? data.subtitle
                            : 'By Mohammad Iqabal',
                        textAlign: TextAlign.left,
                        style: TextStyle(
                            fontSize: 14,
                            color: Color(0xff707070),
                            fontFamily: 'Segoe UI'),
                      ),
                    ],
                  ),
                ),
              ),
            ),
            SizedBox(
              width: 50.0,
            ),
            Align(
                alignment: Alignment.topRight,
                child: Icon(Icons.delete_outline))
          ],
        ),
        Row(
          children: <Widget>[
            Spacer(
              flex: 1,
            ),
            Container(
              height: 30,
              width: 85,
              child: OutlineButton(
                child: Row(
                  children: [
                    Text(
                      (data.btnText != null) ? data.btnText : 'Qty 1',
                      style: TextStyle(fontSize: 12, color: Colors.black),
                    ),
                    SizedBox(
                      width: 1,
                    ),
                    Icon(
                      Icons.arrow_drop_down,
                      color: Color(0xff707070),
                    )
                  ],
                ),
                color: Color(0xffE9E9E9),
                onPressed: onPressed,
                shape: new RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(30.0)),
              ),
            ),
            SizedBox(
              width: 21,
            ),
            Text(
              (data.footerText != null) ? data.footerText : 'USD 4.25',
              style: TextStyle(color: Colors.black, fontSize: 16),
            )
          ],
        )
      ],
    ),
  );
}

==> rapid_widgets_library-0.2.46.tar.gz: lib/custom-borderless-card.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:flutter/widgets.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget customBorderlessCard(
    MaterialCardData data, Function(String, int) callback) {
  void onPressed() {}
  return Container(
    decoration: BoxDecoration(
      border: Border(
        bottom: BorderSide(width: 0.4, color: Color(0xff707070)),
      ),
      color: (data.containerbgColor != null)
          ? data.containerbgColor
          : Colors.white,
    ),
    height: (data.containerHeight != null) ? data.containerHeight : 188.5,
    width: (data.containerWidth != null) ? data.containerWidth : 360,
    child: Column(
      children: <Widget>[
        Row(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Image.network(
              (data.imgPath != null)
                  ? data.imgPath
                  : 'http://104.40.75.137:9003/assets/cms/book2.png',
              height: 113,
              width: 77,
            ),
            Padding(
              padding: const EdgeInsets.only(left: 10.0),
              child: Container(
                width: 193,
                child: Align(
                  alignment: Alignment.centerLeft,
                  child: Column(
                    children: <Widget>[
                      Text(
                        (data.title != null)
                            ? data.title
                            : 'React Fullstack with node/express',
                        style: GoogleFonts.getFont('Roboto',
                            fontSize: 20,
                            color: Color(0xff707070),),
                      ),
                      SizedBox(
                        height: 11,
                      ),
                      Text(
                        (data.subtitle != null)
                            ? data.subtitle
                            : 'By Mohammad Iqabal',
                        textAlign: TextAlign.left,
                        style: GoogleFonts.getFont('Roboto',
                            fontSize: 14,
                            color: Color(0xff707070),),
                      ),
                    ],
                  ),
                ),
              ),
            ),
            SizedBox(
              width: 50.0,
            ),
            Align(
                alignment: Alignment.topRight,
                child: Icon(Icons.delete_outline))
          ],
        ),
        Row(
          children: <Widget>[
            Spacer(
              flex: 1,
            ),
            Container(
              height: 30,
              width: 85,
              child: OutlineButton(
                child: Row(
                  children: [
                    Text(
                      (data.btnText != null) ? data.btnText : 'Qty 1',
                      style: GoogleFonts.getFont('Roboto',fontSize: 12, color: Colors.black),
                    ),
                    SizedBox(
                      width: 1,
                    ),
                    Icon(
                      Icons.arrow_drop_down,
                      color: Color(0xff707070),
                    )
                  ],
                ),
                color: Color(0xffE9E9E9),
                onPressed: onPressed,
                shape: new RoundedRectangleBorder(
                    borderRadius: new BorderRadius.circular(30.0)),
              ),
            ),
            SizedBox(
              width: 21,
            ),
            Text(
              (data.footerText != null) ? data.footerText : 'USD 4.25',
              style: GoogleFonts.getFont('Roboto',color: Colors.black, fontSize: 16),
            )
          ],
        )
      ],
    ),
  );
}
